Rain Assistant
Description: AI-powered coding assistant with voice support

##
Rain Assistant

Ingresa el PIN que aparece en la consola del servidor

## Historial

No hay conversaciones guardadas

Tus conversaciones aparecerán aquí

0 de 5 conversaciones

## Memorias

## Alter Egos

0

Pidele a Rain que cree egos personalizados por chat

## Tienda de Skills

No se encontraron skills

Intenta con otro termino o categoria

## Directores

No hay directores configurados

Crea agentes autonomos que trabajen por horarios

## Bandeja

No hay elementos en la bandeja

Los entregables de los directores apareceran aqui

## Métricas de Uso

No hay datos de métricas disponibles.

## Configuración

### Idioma

### Tema

### Reconocimiento de Voz

### Modo de Voz

### Texto a Voz

Activar TTS

### Dispositivos Conectados

Cargando dispositivos...